@@ -183,8 +183,9 @@ def bioshed_cli_main( args ):
             if len(args) < 3:
                 print('Specify a system or repository to search and type your search terms. Examples:')
                 print('\tbioshed search encode <SEARCH_TERMS>')
+                print('\tbioshed search gdc <SEARCH_TERMS>')
+                print('\tbioshed search tcga <SEARCH_TERMS>')
                 print('\tbioshed search ncbi <SEARCH_TERMS>')
-                print('\tbioshed search local <SEARCH_TERMS>')
                 return
             if str(args[2]).lower() == 'encode':
                 search_terms = str(' '.join(args[3:])).strip()
@@ -204,11 +205,14 @@ def bioshed_cli_main( args ):
             if len(args) < 3:
                 print('Specify a system or repository to download files from. Examples:')
                 print('\tbioshed download encode')
+                print('\tbioshed download gdc')
+                print('\tbioshed download tcga')
                 print('\tbioshed download ncbi')
-                print('\tbioshed download local')
                 return
             if str(args[2]).lower() == 'encode':
                 atlas_encode_utils.download_encode( dict(downloadstr=str(' '.join(args[3:])).strip()))
+            elif str(args[2]).lower() in ['tcga', 'gdc']:
+                atlas_tcga_utils.download_gdc( dict(downloadstr=str(' '.join(args[3:])).strip()))
             elif str(args[2]).lower() == 'ncbi':
                 print('NCBI download coming soon!')
             elif str(args[2]).lower() == 'local':
