@@ -404,36 +404,48 @@ def print_gdc_help():
     """ Prints the command-line help menu when a user types a wrong input or
     when a user just types "bioshed search gdc".
     """
-    print('Welcome to GDC/TCGA dataset search and download, powered by BioShed Atlas.')
-    print('')
-    print('Usage: bioshed search gdc <SEARCH>')
-    print('-or-')
-    print('Usage: bioshed search tcga <SEARCH>\n')
-    print('Examples:\n')
-    print('\t$ bioshed search tcga breast cancer variants')
-    print('\t$ bioshed search gdc --tissue heart --assay rna-seq')
-    print('')
-    print('--tissue and --assay are examples of search categories used to speed up searches.\n')
-    print('Valid search categories are:')
-    print('--tissue / --assay / --celltype / --disease / --filetype / --platform / --species')
-    print('')
-    print('To see a list of valid search terms for a category, you can just type, for example:\n')
-    print('\t$ bioshed search gdc --filetype')
-    print('')
-    print('Once you have performed a search, bioshed will write dataset results to search_gdc.txt in the current directory.')
-    print('To then download those dataset files, you can then run: \n')
-    print('\t$ bioshed download gdc')
+    print('\nWelcome to GDC/TCGA dataset search and download, powered by BioShed Atlas.\n')
+
+    print('------------------------------------------------------------')
+    print('BioShed GDC SEARCH')
+    print('------------------------------------------------------------\n')
+    print('Usage:')
+    print('\tbioshed search gdc <SEARCH>')
+    print('\tbioshed search tcga <SEARCH>\n')
+
+    print('Search Examples:')
+    print('\tGeneral search:\t\t$ bioshed search tcga breast cancer variant call')
+    print('\tSearch by category:\t$ bioshed search gdc --tissue heart --assay rna-seq\n')
+
+    print('Search categories:')
+    print('\t--tissue\tTissue where DNA/RNA/protein material was extracted.')
+    print('\t--assay\tAssay type performed.') 
+    print('\t--disease\tDiagnosed disease type.')
+    print('\t--filetype\tType of data file.')
+    print('\t--platform\tInstrument platform used.')
+    print('\t--species\tHuman, mouse, etc.\n')
+
+    print('To list search terms (example):\n')
+    print('\t$ bioshed search gdc --tissue')
     print('')
+    print('BioShed will write SEARCH results to a file "search_gdc.txt" in the current directory.\n')
+
+    print('------------------------------------------------------------')
+    print('BioShed GDC DOWNLOAD')
+    print('------------------------------------------------------------\n')
+    print('Usage: To download data files listed in "search_gdc.txt", type\n')
+    print('\t$ bioshed download gdc\n')
+
     print('Further refine the files you want using any of the search categories. For example\n')
     print('\t$ bioshed download gdc --filetype fastq')
-    print('\t$ bioshed download gdc --id 6fd3fe64-23ba-4db3-8315-1867bdec277d')
-    print('')
+    print('\t$ bioshed download gdc --id 6fd3fe64-23ba-4db3-8315-1867bdec277d\n')
+    
     print('You can list the files before downloading them, by typing:\n')
-    print('\t$ bioshed download gdc --list')
-    print('')
+    print('\t$ bioshed download gdc --list\n')
+    
     print('You can specify a different output directory, including an AWS S3 remote folder:\n')
-    print('\t$ bioshed download gdc --output s3://my/output/folder')
-    print('')
+    print('\t$ bioshed download gdc --output s3://my/output/folder\n')
+    
     print('By default, existing files in the output directory will be overwritten. To download only new files:\n')
-    print('\t$ bioshed download gdc --update')
+    print('\t$ bioshed download gdc --update\n')
     return
