@@ -1,4 +1,4 @@
-import os, sys, subprocess, json
+import os, sys, subprocess, json, uuid
 
 SCRIPT_DIR = str(os.path.dirname(os.path.realpath(__file__)))
 HOME_PATH = os.path.expanduser('~')
@@ -7,6 +7,10 @@ VALID_REGIONS = ['us-west-2', 'us-west-1', 'us-east-1', 'us-east-2', 'af-south-1
                  'ap-southeast-3', 'ap-south-1', 'ap-northeast-3', 'ap-northeast-2', 'ap-southeast-1', 'ap-southeast-2', 'ap-northeast-1', \
                  'ca-central-1', 'eu-central-1', 'eu-west-1', 'eu-west-2', 'eu-south-1', 'eu-west-3', 'eu-north-1', \
                  'me-south-1', 'me-central-1', 'se-east-1']
+VALID_REGION_NUMBERS = {'1': 'us-west-1', '2': 'us-west-2', '3': 'us-east-1', '4': 'us-east-2', '5': 'ap-south-1', \
+                        '6': 'ap-northeast-1', '7': 'ap-northeast-2', '8': 'ap-southeast-1', '9': 'ca-central-1', '10': 'eu-west-1', '11': 'eu-west-2', \
+                        '12': 'eu-west-3', '13': 'eu-central-1'}
+
 ECR_PUBLIC_REGISTRY = "public.ecr.aws/w7q0j5w1"
 BIOSHED_SERVERLESS_API = "https://hu9ug76w32.execute-api.us-west-2.amazonaws.com/prod"
 
@@ -94,10 +98,22 @@ def bioshed_setup( args ):
     config_file = args['configfile']
     provider_file = args['providerfile']
     main_file = args['mainfile']
+    setup_again = 'Y'
 
     if cloud_provider.lower() in ['aws','amazon']:
-        bioshed_init_aws()
-        provider_file = bioshed_setup_aws( dict(initpath=init_path, configfile=config_file, providerfile=provider_file, mainfile=main_file))
+        cloud_provider = 'aws'
+        if cloud_setup( dict(cloud=cloud_provider, configfile=config_file) ):
+            setup_again = PKEY_INPUT = input('Detected existing setup. Overwrite? (Y/N): ') or 'N'
+        if setup_again.upper()[0] == 'Y':
+            bioshed_init_aws()
+            api_key_file = generate_api_key( dict(cloud=cloud_provider, configfile=config_file))
+            provider_file = bioshed_setup_aws( dict(initpath=init_path, configfile=config_file, providerfile=provider_file, mainfile=main_file, keyfile=api_key_file))
+            env_file = write_env_file( dict(cloud=cloud_provider, initpath=init_path))
+            print('\nBioShed AWS integration setup successful! To setup the core AWS resources, now type:')
+            print('\t$ bioshed deploy core')
+            print('\n Or try one of the following to test your setup:')
+            print('\t$ bioshed run fastqc --help')
+            print('\t$ bioshed run fastqc --example')
     return provider_file
 
 def bioshed_init_macosx():
@@ -171,10 +187,11 @@ def bioshed_init_ubuntu():
 
 def bioshed_init_aws():
     # install aws cli and configure
-    subprocess.call('pip install awscli', shell=True)
-    subprocess.call('curl "https://awscli.amazonaws.com/awscli-exe-linux-x86_64.zip" -o "awscliv2.zip"', shell=True)
-    subprocess.call('unzip awscliv2.zip', shell=True)
-    subprocess.call('sudo ./aws/install', shell=True)
+    if int(subprocess.call('aws --help', shell=True, stdout=subprocess.DEVNULL, stderr=subprocess.DEVNULL)) > 3:
+        subprocess.call('pip install awscli', shell=True)
+        subprocess.call('curl "https://awscli.amazonaws.com/awscli-exe-linux-x86_64.zip" -o "awscliv2.zip"', shell=True)
+        subprocess.call('unzip awscliv2.zip', shell=True)
+        subprocess.call('sudo ./aws/install', shell=True)
     subprocess.call('aws configure', shell=True)
 
 def bioshed_setup_aws( args ):
@@ -183,6 +200,7 @@ def bioshed_setup_aws( args ):
     configfile: config file for important config constants
     providerfile: TF provider file
     mainfile: TF main file
+    keyfile: API key file
     ---
     """
     # setup terraform provider (AWS): https://learn.hashicorp.com/tutorials/terraform/aws-build
@@ -190,18 +208,25 @@ def bioshed_setup_aws( args ):
     INIT_PATH = args['initpath']
     if not os.path.exists(INIT_PATH):
         os.mkdir(INIT_PATH)
+    apikeyfile = args['keyfile'] if 'keyfile' in args else ''
     PROVIDER_FILE = args['providerfile'] # os.path.join(INIT_PATH, 'hs_providers.tf')
     MAIN_FILE = args['mainfile'] # os.path.join(INIT_PATH, 'main.tf')
     AWS_CONFIG_FILE = args['configfile']
     KEYS_FILE = os.path.join(INIT_PATH, 'hsconfig.tf')
-    AWS_REGION = input('Which region do you want to setup your bioshed infrastructure? (ex: us-west-2, us-east-1, eu-south-1, ca-central-1): ')
-    if AWS_REGION not in VALID_REGIONS:
-        AWS_REGION = input('Please type a valid AWS region (default: us-west-2): ') or "us-west-2"
+    AWS_REGION = input('Which region do you want to setup your bioshed infrastructure?\n1: us-west-1 (california)\n2: us-west-2 (oregon) - COMMONLY USED\n3: us-east-1 (virginia) - COMMONLY USED\n4: us-east-2 (ohio)\n5: ap-south-1 (india) - COMMONLY USED\n6: ap-northeast-1 (tokyo)\n7: ap-northeast-2 (seoul)\n8: ap-southeast-1 (singapore)\n9: ca-central-1 (canada)\n10: eu-west-1 (ireland) - COMMONLY USED\n11: eu-west-2 (london)\n12: eu-west-3 (paris)\n13: eu-central-1 (germany)\n\nType a number or a region name: ')
+    if AWS_REGION not in VALID_REGIONS and AWS_REGION not in VALID_REGION_NUMBERS:
+        AWS_REGION = input('Please type a valid number or AWS region (default: us-west-2): ') or "us-west-2"
+    if AWS_REGION in VALID_REGION_NUMBERS:
+        AWS_REGION = VALID_REGION_NUMBERS[AWS_REGION]
     AWS_CONSTANTS_JSON = {}
     AWS_CONSTANTS_JSON["ecr_registry"] = ECR_PUBLIC_REGISTRY
     AWS_CONSTANTS_JSON["aws_region"] = AWS_REGION
 
-    PKEY_INPUT = input('(Needed for running stuff on the cloud): Provide a valid public key for accessing AWS resources (in a separate window, type "ssh-keygen" and paste the public key here) or press ENTER to skip for now: ')
+    if apikeyfile == '':
+        PKEY_INPUT = input('Provide a valid public key for accessing AWS resources (in a separate window, type "bioshed keygen aws" or type "ssh-keygen" and paste the public key here). Press ENTER to skip if not using AWS resources: ')
+    else:
+        PKEY_INPUT = get_public_key( dict(configfile=AWS_CONFIG_FILE))
+
     with open(PROVIDER_FILE,'w') as f:
         f.write('terraform {\n')
         f.write('  required_providers {\n')
@@ -228,6 +253,7 @@ def bioshed_setup_aws( args ):
             )
             f.write('  public_key = "{}"\n'.format(PKEY_INPUT))
             f.write('}\n\n')
+    AWS_CONSTANTS_JSON['setup'] = 'True'
     quick_utils.add_to_json( AWS_CONFIG_FILE, AWS_CONSTANTS_JSON)
     # with open(AWS_CONFIG_FILE,'w') as f:
     #     json.dump(AWS_CONSTANTS_JSON, f)
@@ -251,6 +277,169 @@ def bioshed_teardown( args ):
     os.chdir(cwd)
     return
 
+def write_env_file( args ):
+    """ Writes environment file for use with cloud provider containers.
+
+    cloud: cloud_provider
+    initpath: path of config and init files for bioshed
+    group: key group if multiple credentials are in credentials file. Default: 'default'
+    ---
+    envfile: path and name of env file
+    """
+    cloud = args['cloud'] if 'cloud' in args else 'aws'
+    initpath = args['initpath'] if 'initpath' in args else ''
+    HOME_PATH = os.path.expanduser('~')
+    group = args['group'] if 'group' in args else 'default'
+    envfile = os.path.join(initpath,'.env_{}'.format(cloud))
+    credfile = ''
+    access_key = ''
+    secret_key = ''
+    current_group = ''
+    if initpath != '' and os.path.exists(initpath):
+        if cloud in ['aws','amazon']:
+            credfile = os.path.join(HOME_PATH,'.aws/credentials')
+            if os.path.exists(credfile):
+                with open(credfile,'r') as f:
+                    r = 'start'
+                    while r != '':
+                        r = f.readline()
+                        if 'aws_access_key_id' in r and current_group == group:
+                            access_key = str(r.strip().split('=')[-1]).strip()
+                        elif 'aws_secret_access_key' in r and current_group == group:
+                            secret_key = str(r.strip().split('=')[-1]).strip()
+                        elif '[' in r and ']' in r:
+                            if group in r:
+                                current_group = group
+                            else:
+                                current_group = ''
+            with open(envfile,'w') as fout:
+                fout.write('AWS_ACCESS_KEY_ID={}\n'.format(access_key))
+                fout.write('AWS_SECRET_ACCESS_KEY={}\n'.format(secret_key))
+    return envfile
+
+def get_env_file( args ):
+    """ Gets environment file for cloud provider.
+
+    cloud: cloud provider
+    initpath: init path with all config and env files
+    ---
+    envfile: env file for that cloud provider
+    """
+    cloud = args['cloud'] if 'cloud' in args else 'aws'
+    initpath = args['initpath'] if 'initpath' in args else ''
+    if cloud=='aws' and initpath != '':
+        return os.path.join(initpath,'.env_{}'.format(cloud))
+    else:
+        return ''
+
+def cloud_setup( args ):
+    """ Checks if cloud provider already setup in Bioshed. (bioshed setup [cloud])
+    Assumes that config file has a key 'setup = True' or 'setup' = 'Yes' if setup properly.
+
+    cloud: which cloud provider
+    configfile: config file for cloud provider
+    ---
+    boolean: True/False is cloud setup already?
+
+    """
+    isSetup = False
+    cloud = args['cloud'] if 'cloud'in args else 'aws'
+    configfile = args['configfile'] if 'configfile' in args else ''
+    if os.path.exists(configfile):
+        config_json = quick_utils.loadJSON(configfile)
+        is_cloud_setup = config_json['setup'] if 'setup' in config_json else 'False'
+        if is_cloud_setup.upper()[0] in ['T','Y']:
+            isSetup = True
+    return isSetup
+
+def cloud_configured( args ):
+    """ Checks if a cloud provider is configured properly
+
+    cloud: which cloud provider to check. If empty, then check all.
+    ---
+    boolean: True/False if cloud is configured or not
+    """
+    cloud = args['cloud'] if 'cloud' in args else 'all'
+    pnum = 127
+    if cloud in ['aws','amazon','all']:
+        pnum = min(int(subprocess.call('aws s3 ls', shell=True, stdout=subprocess.DEVNULL, stderr=subprocess.DEVNULL)), pnum)
+    if cloud in ['gcp','all']:
+        pnum = min(int(subprocess.call('gcp --help', shell=True, stdout=subprocess.DEVNULL, stderr=subprocess.DEVNULL)), pnum)
+
+    if pnum > 3:
+        return False
+    else:
+        return True
+
+def cloud_core_setup( args ):
+    """ Checks if cloud core is setup (i.e., bioshed deploy core) has been run).
+
+    configfile: config file for core setup.
+    ---
+    boolean: True/False if cloud is configured or not
+    """
+    isCoreSetup = False
+    configfile = args['configfile'] if 'configfile' in args else ''
+    if configfile!='' and os.path.exists(configfile):
+        config_json = quick_utils.loadJSON(configfile)
+        is_core_setup = config_json['core_setup'] if 'core_setup' in config_json else 'N'
+    if is_core_setup.upper()[0] in ['Y','T']:
+        isCoreSetup = True
+    return isCoreSetup
+
+def generate_api_key( args ):
+    """ Generates an API key for a cloud provider.
+
+    cloud: which cloud provider to generate key for.
+    configfile: cloud provider config file
+    ---
+    keyfile: name of generated public key file
+
+    [NOTE] https://stackoverflow.com/questions/43235179/how-to-execute-ssh-keygen-without-prompt
+
+    """
+    cloud = args['cloud'] if 'cloud' in args else 'aws'
+    configfile = args['configfile'] if 'configfile' in args else ''
+    CONFIG_JSON = {}
+    unique_key_id = str(uuid.uuid4())[0:4]
+    keyfile = os.path.join(INIT_PATH, 'bioshed_{}_{}'.format(cloud, unique_key_id))
+    while os.path.exists(keyfile):
+        # in the rare event that key with unique id already exists, generate a new one
+        unique_key_id = str(uuid.uuid4())[0:4]
+        keyfile = os.path.join(INIT_PATH, 'bioshed_{}_{}'.format(cloud, unique_key_id))
+    if configfile != '':
+        # generate a new public/private key pair for cloud API.
+        rcode = subprocess.call("ssh-keygen -t rsa -N '' -f {}".format(keyfile), shell=True)
+        CONFIG_JSON['apikeyfile'] = keyfile
+        if int(rcode) == 0:
+            print('Public/private key generated at {}'.format(keyfile))
+        # reference key file name within config file
+        quick_utils.add_to_json( configfile, CONFIG_JSON)
+    else:
+        print('ERROR: No key generated. Must specify a cloud config file.')
+    return keyfile
+
+def get_public_key( args ):
+    """ Gets public key for a given key file specified within config file.
+
+    configfile: config file where key file name is stored
+    ---
+    pubkey: public key
+    """
+    configfile = args['configfile']
+    keyfile = ''
+    pubkey = ''
+
+    if os.path.exists(configfile):
+        configjson = quick_utils.loadJSON(configfile)
+        keyfile = configjson['apikeyfile']
+    if keyfile != '' and os.path.exists(keyfile+'.pub'):
+        with open(keyfile+'.pub','r') as f:
+            # takes last line as key
+            for r in f:
+                pubkey = r.strip()
+    return pubkey
+
 def bioshed_run_help():
     """ Help menu for bioshed run.
     """
@@ -274,6 +463,7 @@ def bioshed_run_help():
 
     Examples using hybrid environment:
         $ bioshed run bedtools merge s3://folder1/test.bed out::/data/
+        $ bioshed run fastqc s3://bioshed-examples/fastq/rnaseq_mouse_test_tiny1_R1.fastq.gz out::local
 
     Output:
         bioshed.run.out                 All text printed to the console (STDOUT)
@@ -281,6 +471,7 @@ def bioshed_run_help():
         run.<TIMESTAMP>.log             Run log JSON
         out::<OUTPUT_FOLDER>            Output folder for all log and data files.
                                         If no output folder is specified, then the input folder is used as the output folder.
+                                        You can explicitly specify local by "out::local"
 
     optional CONFIG-ARGS:
         --local                Run application on local system. Requires docker to be installed.
@@ -322,5 +513,5 @@ def biocontainers_help():
     You must know the image name and tag of the biocontainer you want to run.
     For more information, refer to the Biocontainers documentation at:
     https://biocontainers.pro/
-    
+
     """)
